@@ -8,10 +8,11 @@ use Try::Tiny;
 use Sys::Hostname;
 use Plack::Util;
 use Class::Inspector;
+use List::Util qw(any);
 use Scalar::Util qw(blessed);
 use Encode qw(encode decode);
 
-our $VERSION = '2.01_02';
+our $VERSION = '2.01_03';
 
 # Basic attributes
 attr -host => hostname;
@@ -274,10 +275,16 @@ sub psgi {
     catch {
         my $exception = $_;
 
+        # CONTEXT CHANGE: we need to clear response state because anything that
+        # was rendered beforehand is no longer valid. Body and code will be
+        # replaced automatically with render methods, but headers must be
+        # cleared explicitly
+        $res->headers->clear;
+
         if (blessed $exception && $exception->isa('Kelp::Exception')) {
-            # No logging here, since it is a message for the user with a code
-            # rather than a real exceptional case
-            # (Nothing really broke, user code invoked this)
+            # only log it as an error if the body is present
+            $self->logger( 'error', $exception->body )
+                if $self->can('logger') && defined $exception->body;
 
             $res->render_exception($exception);
         }
@@ -287,7 +294,7 @@ sub psgi {
             # Log error
             $self->logger( 'critical', $message ) if $self->can('logger');
 
-            # Render 500
+            # Render an application erorr (hides details on production)
             $res->render_500($exception);
         }
 
@@ -329,6 +336,11 @@ sub named {
 # Utility
 #----------------------------------------------------------------
 
+sub is_production {
+    my $self = shift;
+    return any { lc $self->mode eq $_ } qw(deployment production);
+}
+
 sub url_for {
     my ( $self, $name, @args ) = @_;
     my $result = $name;
@@ -745,6 +757,11 @@ application (based on configuration).
 
 Shortcut methods, which encode or decode a string using the application's current L</charset>.
 
+=head2 is_production
+
+Returns whether the application is in production mode. Checks if L</mode> is
+either C<deployment> or C<production>.
+
 =head1 AUTHOR
 
 Stefan Geneshky - minimal <at> cpan.org
