@@ -95,8 +95,8 @@ sub is_json {
 sub charset {
     my $self = shift;
     return undef unless $self->content_type;
-    return undef unless $self->content_type =~ m{;\s*charset=([^;\$]+)};
-    return $1;
+    return undef unless $self->content_type =~ m{;\s*charset=([^;\$]+)}i;
+    return lc $1;
 }
 
 sub charset_decode {
@@ -107,7 +107,7 @@ sub charset_decode {
         # If the charset is unsupported by Encode, try to decode using
         # application charset. Worst case scenario is a server error with code
         # 500
-        state $supported = { map { $_ => $_ } Encode->encodings(':all') };
+        state $supported = { map { lc $_ => $_ } Encode->encodings(':all') };
         my $charset = $supported->{$self->charset} // $self->app->charset;
 
         return decode $charset, $string;
@@ -136,7 +136,7 @@ sub json_content {
     return undef unless $self->is_json;
 
     return try {
-        $self->app->json->decode( $self->raw_body );
+        $self->app->_json_internal->decode( $self->content );
     }
     catch {
         undef;
@@ -232,10 +232,10 @@ Starting with version 2.01, Kelp::Request simplifies input handling and
 improves correctness by automatically decoding path, query parameters and body
 parameters.
 
-Headers (so cookies as well) are unaffected, as they aren't
-consistently supported outside of ASCII range. JSON and session are configured
-separately in modules and middlewares, so they must themselves do the proper
-decoding.
+Headers (so cookies as well) are unaffected, as they aren't consistently
+supported outside of ASCII range. JSON now decodes request data into the proper
+charset instead of flat utf8 if so configured. Sessions are configured
+separately in middlewares, so they must themselves do the proper decoding.
 
 Following methods will return values decoded with charset either from
 C<Content-Type> header or the one specified in the app's configuration:
